﻿using BlacksmithWorkshopContracts.BindingModels;
using BlacksmithWorkshopContracts.BusinessLogicContracts;
using BlacksmithWorkshopContracts.BusinessLogicsContracts;
using BlacksmithWorkshopContracts.SearchModels;
using Microsoft.Extensions.Logging;

namespace BlacksmithWorkshopView
{
	public partial class FormFillStore : Form
	{
		private readonly ILogger _logger;
		private readonly IStoreLogic _logicS;
		private readonly IManufactureLogic _logicM;
		public FormFillStore(ILogger<FormCreateOrder> logger, IStoreLogic logicS, IManufactureLogic logicM)
		{
			InitializeComponent();
			_logger = logger;
			_logicS = logicS;
			_logicM = logicM;
		}
		private void FormFillStore_Load(object sender, EventArgs e)
		{
			_logger.LogInformation("Загрузка магазинов и изделий");
			var listS = _logicS.ReadList(null);
			if (listS != null)
			{
				comboBoxStore.DisplayMember = "StoreName";
				comboBoxStore.ValueMember = "Id";
				comboBoxStore.DataSource = listS;
				comboBoxStore.SelectedItem = null;
			}
			var listM = _logicM.ReadList(null);
			if (listM != null)
			{
				comboBoxManufacture.DisplayMember = "ManufactureName";
				comboBoxManufacture.ValueMember = "Id";
				comboBoxManufacture.DataSource = listM;
				comboBoxManufacture.SelectedItem = null;
			}
		}
		private void ButtonSave_Click(object sender, EventArgs e)
		{
			if (comboBoxStore.SelectedValue == null)
			{
				MessageBox.Show("Выберите магазин", "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
				return;
			}
			if (comboBoxManufacture.SelectedValue == null)
			{
				MessageBox.Show("Выберите изделие", "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
				return;
			}
			_logger.LogInformation("Пополнение магазина");
			try
			{
				var addedManufacture = _logicM.ReadElement(new ManufactureSearchModel
				{
					Id = Convert.ToInt32(comboBoxManufacture.SelectedValue)
				});
				if (addedManufacture == null)
				{
					return;
				}
				var operationResult = _logicS.AddManufacture(addedManufacture, new StoreSearchModel
				{
					Id = Convert.ToInt32(comboBoxStore.SelectedValue)
				}, Convert.ToInt32(textBoxCount.Text));
				if (!operationResult)
				{
					throw new Exception("Ошибка при пополнении магазина. Дополнительная информация в логах.");
				}
				MessageBox.Show("Сохранение прошло успешно", "Сообщение", MessageBoxButtons.OK, MessageBoxIcon.Information);
				DialogResult = DialogResult.OK;
				Close();
			}
			catch (Exception ex)
			{
				_logger.LogError(ex, "Ошибка пополнения магазина");
				MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
			}
		}
		private void ButtonCancel_Click(object sender, EventArgs e)
		{
			DialogResult = DialogResult.Cancel;
			Close();
		}
	}
}