﻿using BlacksmithWorkshopContracts.BindingModels;
using BlacksmithWorkshopContracts.ViewModels;
using BlacksmithWorkshopDataModels.Models;

namespace BlacksmithWorkshopListImplement.Models
{
	public class Store : IStoreModel
	{
		public int Id { get; private set; }
		public string StoreName { get; private set; } = string.Empty;
		public string Address { get; private set; } = string.Empty;
		public DateTime OpeningDate { get; private set; }
		public List<(IManufactureModel, int)> Manufactures { get; private set; } = new();
		public static Store? Create(StoreBindingModel? model)
		{
			if (model == null)
			{
				return null;
			}
			return new Store()
			{
				Id = model.Id,
				StoreName = model.StoreName,
				Address = model.Address,
				OpeningDate = model.OpeningDate,
				Manufactures = new()
			};
		}
		public void Update(StoreBindingModel? model)
		{
			if (model == null)
			{
				return;
			}
			StoreName = model.StoreName;
			Address = model.Address;
			OpeningDate = model.OpeningDate;
			Manufactures = model.Manufactures;
		}
		public StoreViewModel GetViewModel => new()
		{
			Id = Id,
			StoreName = StoreName,
			Address = Address,
			OpeningDate = OpeningDate,
			Manufactures = Manufactures
		};
	}
}
